package es.misadiaria.misadiaria.commons;

import android.content.Intent;
import android.os.Bundle;
import android.support.design.widget.NavigationView;
import android.support.v4.app.DialogFragment;
import android.support.v4.view.GravityCompat;
import android.support.v4.widget.DrawerLayout;
import android.support.v7.app.ActionBarDrawerToggle;
import android.support.v7.app.AppCompatActivity;
import android.support.v7.widget.Toolbar;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.TextView;

import java.util.Calendar;
import java.util.GregorianCalendar;

import es.misadiaria.misadiaria.MainActivity;
import es.misadiaria.misadiaria.R;
import es.misadiaria.misadiaria.lecturas.EvangelioActivity;
import es.misadiaria.misadiaria.lecturas.EvangelioAssetsImpl;
import es.misadiaria.misadiaria.lecturas.EvangelioFacade;
import es.misadiaria.misadiaria.oraciones.AvemariaActivity;
import es.misadiaria.misadiaria.oraciones.CredoActivity;
import es.misadiaria.misadiaria.oraciones.CruzActivity;
import es.misadiaria.misadiaria.oraciones.GloriaActivity;
import es.misadiaria.misadiaria.oraciones.PadrenuestroActivity;
import es.misadiaria.misadiaria.oraciones.SalveActivity;
import es.misadiaria.misadiaria.santoral.SantoralActivity;
import es.misadiaria.misadiaria.santoral.SantoralAssetsImpl;
import es.misadiaria.misadiaria.santoral.SantoralFacade;
import es.misadiaria.misadiaria.utils.MisaDiariaDateUtils;

public class CommonMisaDiariaActivity extends AppCompatActivity
        implements NavigationView.OnNavigationItemSelectedListener {

    private static Calendar calendar;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        if (CommonMisaDiariaActivity.getCalendar() == null) {
            CommonMisaDiariaActivity.setCalendar(GregorianCalendar.getInstance());
        }
    }

    protected void initializeToolbarsAndNavigation() {

        Toolbar toolbar = (Toolbar) findViewById(R.id.toolbar);
        setSupportActionBar(toolbar);

        DrawerLayout drawer = (DrawerLayout) findViewById(R.id.drawer_layout);
        ActionBarDrawerToggle toggle = new ActionBarDrawerToggle(
                this, drawer, toolbar, R.string.navigation_drawer_open, R.string.navigation_drawer_close);
        drawer.setDrawerListener(toggle);
        toggle.syncState();

        NavigationView navigationView = (NavigationView) findViewById(R.id.nav_view);
        navigationView.setNavigationItemSelectedListener(this);

    }

    @Override
    public void onBackPressed() {
        CommonMisaDiariaActivity.setCalendar(GregorianCalendar.getInstance());
        DrawerLayout drawer = (DrawerLayout) findViewById(R.id.drawer_layout);
        if (drawer.isDrawerOpen(GravityCompat.START)) {
            drawer.closeDrawer(GravityCompat.START);
        } else {
            super.onBackPressed();
        }
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_main, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        return super.onOptionsItemSelected(item);
    }


    @Override
    public boolean onNavigationItemSelected(MenuItem item) {

        switch (item.getItemId()) {
            case R.id.nav_inicio:
                launchActivity(MainActivity.class);
                break;
            case R.id.nav_santoral:
                launchActivity(SantoralActivity.class);
                break;
            case R.id.nav_evangelio:
                launchActivity(EvangelioActivity.class);
                break;
            case R.id.nav_cruz:
                launchActivity(CruzActivity.class);
                break;
            case R.id.nav_padrenuestro:
                launchActivity(PadrenuestroActivity.class);
                break;
            case R.id.nav_avemaria:
                launchActivity(AvemariaActivity.class);
                break;
            case R.id.nav_gloria:
                launchActivity(GloriaActivity.class);
                break;
            case R.id.nav_salve:
                launchActivity(SalveActivity.class);
                break;
            case R.id.nav_credo:
                launchActivity(CredoActivity.class);
                break;
        }

        DrawerLayout drawer = (DrawerLayout) findViewById(R.id.drawer_layout);
        drawer.closeDrawer(GravityCompat.START);
        return true;

    }

    private void launchActivity(Class<?> activity) {
        if (!this.getClass().equals(activity)) {
            startActivity(new Intent(this, activity));
            this.finish();
        }
    }

    public void showDatePickerDialog(View view) {
        DialogFragment newFragment = new DatePickerFragment();
        newFragment.show(getSupportFragmentManager(), "datePicker");
    }

    public static Calendar getCalendar() {
        return calendar;
    }

    public static void setCalendar(Calendar calendar) {
        CommonMisaDiariaActivity.calendar = calendar;
    }

    protected void setFechaEscogida() {
        TextView fechaEscogida = (TextView) findViewById(R.id.fechaEscogida);
        fechaEscogida.setText(MisaDiariaDateUtils.getDaySpanishFormat(CommonMisaDiariaActivity.getCalendar()));
    }

    public void setSantoral() {
        TextView santoral = (TextView) findViewById(R.id.santoral);
        SantoralFacade santoralFacade = new SantoralAssetsImpl();
        santoral.setText(santoralFacade.getSantoralDia(this, CommonMisaDiariaActivity.getCalendar()));
    }

    public void setEvangelio() {
        TextView evangelio = (TextView) findViewById(R.id.evangelio);
        EvangelioFacade evangelioFacade = new EvangelioAssetsImpl();
        evangelio.setText(evangelioFacade.getEvangelioDia(this, CommonMisaDiariaActivity.getCalendar()));
    }

}
